@@ -46,6 +46,8 @@ function (X, k = 0, sca = "mad", scores = TRUE)
 
     m <- list()
     for (i in 1:length(method)) {
+      print(paste("method", method[i], "will be applied"))
+      flush.console() 
         if( method[i] %in% c("simple", "single", "onedims", "pca", 
     "pppca", "clustpca", "clustpppca", "mdav", "influence", "rmd", "clustmcdpca","mcdpca")){
         m[[i]] <- microaggregation(x = x, method = method[i], 
@@ -56,7 +58,19 @@ function (X, k = 0, sca = "mad", scores = TRUE)
         if( substring(method[i],1,8) == "addNoise" ){
           m[[i]] <- addNoise(x, noise=noise, method=substring(method[i],11,nchar(method[i])))
         }
+        if( method[i] == "dataGen" ){ 
+          d <- dataGen(x, n=dim(x)[1])
+          d <- list(x = x, xm = d)
+          class(d) <- "micro"
+          m[[i]] <- d
+        }
+        #print(i)
+        #flush.console()
+
     }
+    print("calculating summary statistics")
+    flush.console()
+    #save(m, file="mres.Rdata")
     s <- list()
     s <- lapply(m, summary, robCov = FALSE, robReg = FALSE)
     g <- data.frame(amean = round(s[[1]][[3]], 3), amedian = round(s[[1]][[4]], 
@@ -65,7 +79,15 @@ function (X, k = 0, sca = "mad", scores = TRUE)
         3), acor = round(s[[1]][[10]], 3), acors = round(s[[1]][[12]], 
         3), adlm = round(s[[1]][[13]], 3), apcaload = round(s[[1]][[15]], 
         3), apppcaload = round(s[[1]][[16]], 3), atotals = round(s[[1]][[19]], 
-        3), pmtotals = round(s[[1]][[20]], 3))
+        3), pmtotals = round(s[[1]][[20]], 3),
+        util1 = round(s[[1]][[21]], 3),
+        deigenvalues = round(s[[1]][[22]], 3),
+        risk0 = round(s[[1]][[23]], 3),
+        risk1 = round(s[[1]][[24]], 3),
+        risk2 = round(s[[1]][[25]], 3),
+       wrisk1 = round(s[[1]][[26]], 3),
+       wrisk2 = round(s[[1]][[27]], 3)       
+        )
     if (length(s) > 1) {
         for (i in 2:length(s)) {
             g2 <- data.frame(amean = round(s[[i]][[3]], 3), amedian = round(s[[i]][[4]], 
@@ -74,7 +96,15 @@ function (X, k = 0, sca = "mad", scores = TRUE)
                 3), acor = round(s[[i]][[10]], 3), acors = round(s[[i]][[12]], 
                 3), adlm = round(s[[i]][[13]], 3), apcaload = round(s[[i]][[15]], 
                 3), apppcaload = round(s[[i]][[16]], 3), atotals = round(s[[i]][[19]], 
-                3), pmtotals = round(s[[i]][[20]], 3))
+                3), pmtotals = round(s[[i]][[20]], 3),
+         util1 = round(s[[i]][[21]], 3),
+        deigenvalues = round(s[[i]][[22]], 3),
+        risk0 = round(s[[i]][[23]], 3),
+        risk1 = round(s[[i]][[24]], 3),
+        risk2 = round(s[[i]][[25]], 3),
+       wrisk1 = round(s[[i]][[26]], 3),
+       wrisk2 = round(s[[i]][[27]], 3)                 
+                )
             g <- rbind(g, g2)
         }
     }
